package net.antonioshome.clexec;

import java.util.logging.Logger;
import net.antonioshome.clexec.UnixCommandLineExecutor;

/**
 * A factory used to return a ProcessExecutor that is appropriate for
 *   this operating system.
 * @author Antonio Vieiro (antonio@antonioshome.net)
 * @author $Author: $
 * @version $Revision: $
 */
public final class ProcessExecutorFactory
{
  private ProcessExecutorFactory() {}
  /**
   * Returns a ProcessExecutor suitable for this platform.
   * @return A ProcessExecutor suitable for this platform.
   */
  public static ProcessExecutor getDefault()
  {
    String osName = System.getProperty("os.name").toLowerCase();

    if ( osName.startsWith("linux") )
      return new UnixCommandLineExecutor();
    else if ( osName.startsWith("windows") )
      return new WindowsCommandLineExecutor();
    else if ( osName.startsWith("sunos") )
      return new UnixCommandLineExecutor();
    else if ( osName.startsWith("mac os x") )
      return new UnixCommandLineExecutor();
    else
    {
      Logger.getLogger( ProcessExecutorFactory.class.getName()  ).warning( "Unknown OS. Please contact antonio@antonioshome.net and inform Antonio that your O/S is a '" + osName + "'");
      return new UnixCommandLineExecutor();
    }
  }
}
