package net.antonioshome.clexec;

import java.io.InputStream;
import java.io.PrintStream;

/**
 * ProcessStreams is used to redirect stdin, stdout and stderr of a
 *   running process to specific Java input and output streams.
 * @author Antonio Vieiro (antonio@antonioshome.net)
 * @author $Author: $
 * @version $Revision: $
 */
public interface ProcessStreams
{
  /**
   * Returns a PrintStream used to write the standard output of a process.
   * @return a PrintStream where all the standard output of a process is
   *   to be written to.
   */
  public PrintStream getStdout();
  /**
   * Returns a PrintStream used to write the standard error of a process.
   * @return a PrintStream where all the standard error of a process is to
   *   be printed.
   */
  public PrintStream getStderr();
  /**
   * Returns an InputStream used to read standard input for a process.
   * @return an InputStream used to read input for the process.
   */
  public InputStream getStdin();
  /**
   * A default ProcessStreams that redirects a process input, output and
   * stderr to Java's System.in, System.out and System.err
   */
  public ProcessStreams DEFAULT =
    new ProcessStreams()
  {
    public PrintStream getStdout()
    {
      return System.out;
    }

    public PrintStream getStderr()
    {
      return System.err;
    }

    public InputStream getStdin()
    {
      return System.in;
    }
  };

}
